pub struct MemoryStats {
pub total: usize,
pub available: usize,
pub used: usize,
}Expand description
Memory information of a device at some point in time.
Fields
total: usizeThe total local memory, in bytes. This value should always be the same for the same Device.
available: usizeThe current amount of local memory that is available for new allocations, in bytes.
used: usizeThe current amount of local memory in use by the system, in bytes.