DeviceHandle

Trait DeviceHandle 

pub trait DeviceHandle: Send + Sync {
    // Required methods
    fn name(&self) -> &str;
    fn kind(&self) -> DeviceKind;
    fn backend(&self) -> BackendId;
    fn current_memory_stats(&self) -> MemoryStats;
}
Trait for internal device handles.

Required Methods

fn name(&self) -> &str

Return the name of this device.

fn kind(&self) -> DeviceKind

Return the hardware type of this device.

fn backend(&self) -> BackendId

Return the identifier of the Backend that owns this device handle.

fn current_memory_stats(&self) -> MemoryStats

Return the memory statistics of this device at this point in time.

Implementors