pub trait DeviceHandle: Send + Sync {
// Required methods
fn name(&self) -> &str;
fn kind(&self) -> DeviceKind;
fn backend(&self) -> BackendId;
fn current_memory_stats(&self) -> MemoryStats;
}Expand description
Trait for internal device handles.
Required Methods
Sourcefn kind(&self) -> DeviceKind
fn kind(&self) -> DeviceKind
Return the hardware type of this device.
Sourcefn backend(&self) -> BackendId
fn backend(&self) -> BackendId
Return the identifier of the Backend that owns this device handle.
Sourcefn current_memory_stats(&self) -> MemoryStats
fn current_memory_stats(&self) -> MemoryStats
Return the memory statistics of this device at this point in time.